grab.spider.service.task_dispatcher — Grab 0.6.41 documentation

# `grab.spider.service.task_dispatcher`

## Module Contents

### Classes

`TaskDispatcherService` |

class grab.spider.service.task_dispatcher.TaskDispatcherService(fatal_error_queue: queue.Queue[grab.spider.interface.FatalErrorQueueItem], process_service_result: collections.abc.Callable[[Any, grab.spider.task.Task, None | dict[str, Any]], Any])

  Bases: `grab.spider.service.base.BaseService`

  start() → None
  worker_callback(worker: grab.spider.service.base.ServiceWorker) → None